package com.bcb.master.adapter

import android.app.Activity
import android.content.Intent
import android.text.TextUtils
import android.widget.ImageView
import com.bcb.master.MasterApplication
import com.bcb.master.R
import com.bcb.master.model.VideoUserTimeBean
import com.bcb.master.ui.ImageDetialActivity
import com.blankj.utilcode.util.TimeUtils
import com.bumptech.glide.Glide
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.chad.library.adapter.base.util.MultiTypeDelegate
import com.google.gson.Gson
import com.loopj.http.entity.QXQChatBean

class QXQChatAdapter// 内容类型: text-文字 image-图片 audio-音频 video-视频 call-音视频通话
 : BaseQuickAdapter<QXQChatBean.Message, BaseViewHolder>(null) {

    val TEXT_MY = 1//提问——右
    val TEXT_OTHER = 2 //助手——左
    val IMAGE_MY = 3 //图片-右
    val IMAGE_OTHER = 4 //其他图片-左
    val AUDIO_MY = 5
    val AUDIO_OTHER = 6
    val VIDEO = 5//视频-左
    val CALL = 6//视频结束标识
    val ANSWER_MSG = 7//咨询问题详情
    var askAvatar :String =""
    var answerAvatar :String =""

    init {
        val userBean =MasterApplication.getInstance().userBean
        if (userBean!=null)
        {
            setMultiTypeDelegate(object: MultiTypeDelegate<QXQChatBean.Message>(){

                override fun getItemType(message: QXQChatBean.Message): Int {
                    when(message.content_type)
                    {
                        // 内容类型: text-文字 image-图片 audio-音频 video-视频 call-音视频通话
                        "text"->{
                            if (TextUtils.equals(message.uid,userBean.uid)){
                                return TEXT_MY
                            }else{
                                return TEXT_OTHER
                            }
                        }
                        "image"->{
                            if (TextUtils.equals(message.uid,userBean.uid)){
                                return IMAGE_MY
                            }else{
                                return IMAGE_OTHER
                            }
                        }
                        "audio"->{
                            if (TextUtils.equals(message.uid,userBean.uid)){
                                return AUDIO_MY
                            }else{
                                return AUDIO_OTHER
                            }
                        }
                        "video"->{
                            return VIDEO
                        }
                        "call"->{
                            return CALL
                        }
                        "ANSWER_MSG"->{
                            return  ANSWER_MSG
                        }
                    }
                    return 0
                }
            })
            getMultiTypeDelegate()!!.registerItemType(TEXT_MY,R.layout.activity_qxq_chat_mine)
                    .registerItemType(TEXT_OTHER,R.layout.activity_qxq_chat_other)
                    .registerItemType(IMAGE_MY,R.layout.activity_qxq_chat_mine_img)
                    .registerItemType(IMAGE_OTHER,R.layout.activity_qxq_chat_other_img)
                    .registerItemType(AUDIO_MY,R.layout.activity_chat_mine_voice)
                    .registerItemType(AUDIO_OTHER,R.layout.activity_chat_other_voice)
                    .registerItemType(VIDEO,R.layout.activity_chat_other_video)
                    .registerItemType(CALL,R.layout.activity_qxq_chat_video_usetime)
                    .registerItemType(ANSWER_MSG,R.layout.activity_chat_expert_tip)
        }
    }
    fun setAvatar(askAvatar:String,answerAvatar:String){
        this.askAvatar = askAvatar
        this.answerAvatar = answerAvatar
    }
    override fun convert(holder: BaseViewHolder, item: QXQChatBean.Message) {
        var avatar = ""
        when(holder.itemViewType)
        {
            TEXT_MY->{
                avatar = answerAvatar
                holder.setText(R.id.tv_content,item.content)
                if (!TextUtils.isEmpty(item.create_time))
                {
                    val millis2String = TimeUtils.millis2String((item.create_time)!!.toLong()*1000, "yyyy-MM-dd HH:mm")
                    holder.setText(R.id.tv_time,millis2String)
                }
                holder.addOnClickListener(R.id.tv_chat)
                when(item.sendStatus)
                {
                    0->{
                        holder.setVisible(R.id.pb_chat, true)
                        holder.setVisible(R.id.tv_time,false)
                        holder.setVisible(R.id.tv_chat,false)
                    }
                    1->{
                        holder.setVisible(R.id.pb_chat, false)
                        holder.setVisible(R.id.tv_time,true)
                        holder.setVisible(R.id.tv_chat,false)
                    }
                    2->{
                        holder.setVisible(R.id.pb_chat, false)
                        holder.setVisible(R.id.tv_time,true)
                        holder.setVisible(R.id.tv_chat,true)
                    }
                }
            }
            TEXT_OTHER->{
                avatar = askAvatar

                holder.setText(R.id.tv_content,item.content)
                val millis2String = TimeUtils.millis2String((item.create_time)!!.toLong()*1000, "yyyy-MM-dd HH:mm")
                holder.setText(R.id.tv_time,millis2String)
            }
            IMAGE_MY ->{
                avatar = answerAvatar
                var img = holder.getView(R.id.img_content) as ImageView
                Glide.with(mContext).load(item.content).into(img)
                val millis2String = TimeUtils.millis2String((item.create_time)!!.toLong()*1000, "yyyy-MM-dd HH:mm")
                holder.setText(R.id.tv_time,millis2String)
                img.setOnClickListener{
                    val intent = Intent(mContext, ImageDetialActivity::class.java)
                    intent.putExtra("url", item.content)
                    mContext.startActivity(intent)
                    (mContext as Activity).overridePendingTransition(0, 0)
                }
            }
            IMAGE_OTHER ->{
                avatar = askAvatar
                var img = holder.getView(R.id.img_content) as ImageView
                Glide.with(mContext).load(item.content).into(img)
                val millis2String = TimeUtils.millis2String((item.create_time)!!.toLong()*1000, "yyyy-MM-dd HH:mm")
                holder.setText(R.id.tv_time,millis2String)
                img.setOnClickListener{
                    val intent = Intent(mContext, ImageDetialActivity::class.java)
                    intent.putExtra("url", item.content)
                    mContext.startActivity(intent)
                    (mContext as Activity).overridePendingTransition(0, 0)
                }
            }
            CALL->{
                avatar = askAvatar
                val usetime = Gson().fromJson(item.content, VideoUserTimeBean::class.java)
                holder.setText(R.id.tv_title,usetime.desc)
                holder.setText(R.id.tv_content,usetime.duration_format)
                val millis2String = TimeUtils.millis2String((item.create_time)!!.toLong()*1000, "yyyy-MM-dd HH:mm")
                holder.setText(R.id.tv_time,millis2String)
            }
            ANSWER_MSG->{

            }
        }
        var iv_avatar = holder.getView<ImageView>(R.id.iv_user)
        Glide.with(mContext)
                .load(avatar)
                .into(iv_avatar)
    }


}