package com.bcb.master.ui

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.widget.EditText
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.RelativeLayout
import android.widget.TextView

import com.bcb.log.BCBLog
import com.bcb.master.AppConstants
import com.bcb.master.MasterApplication
import com.bcb.master.R
import com.bcb.master.model.UserBean
import com.bcb.master.model.UserBeanResponse
import com.bcb.master.utils.HttpUtilInterFace
import com.bcb.master.utils.HttpUtils
import com.bcb.master.utils.ToastUtils
import com.loopj.http.bcb.CMHttpSender
import com.loopj.http.bcb.CMJsonCallback
import com.loopj.http.bcb.CMRequestType
import com.loopj.http.entity.ChangeCommonResult
import com.loopj.http.entity.Config
import com.loopj.http.entity.ConfigResponseEntity
import com.loopj.http.entity.MechanicCommonBean

import org.apache.http.Header
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

import java.util.ArrayList
import java.util.HashMap

import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import kotlinx.android.synthetic.main.activity_chat_common.*
import kotlinx.android.synthetic.main.activity_title_white.*
import org.jetbrains.anko.act

/**
 * @author bcb
 * *
 * @date 2018/2/10
 */

class ChatCommonActivity : BaseActivity(), CMJsonCallback ,View.OnClickListener{



    private lateinit var userBean: UserBean
    private val TO_ADD_COMMON = 30//去添加常用语
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_chat_common)
        ButterKnife.bind(this)
        initView()
        initData()
    }

    private fun initData() {
        userBean = MasterApplication.getInstance().userBean
        var common_sentences: ArrayList<String>? = null
        try {
            val config = MasterApplication.getConfig(this)
            val mechanic = config.mechanic
            common_sentences = mechanic.common_sentences
        } catch (e: Exception) {
            BCBLog.d("", e)
        }
        if(common_sentences == null)
        {
            common_sentences = ArrayList()
        }
        initCommon(common_sentences)

    }

    private fun initCommon(common_sentences: ArrayList<String>?) {
        ll_common_list!!.removeAllViews()
        updateMechanic()
        //初始化补充内容
        var size = 0
        if (common_sentences != null) {
            size = common_sentences.size
        }
        if (size <= 0)
        {
            ll_common_list.visibility = View.GONE
        }else{
            ll_common_list.visibility = View.VISIBLE
        }
        for (i in 0..size - 1) {
            val view = LayoutInflater.from(this).inflate(R.layout.item_chat_common, null)
            val tv_common1 = view.findViewById(R.id.tv_common1) as TextView
            val iv_delete_common = view.findViewById(R.id.iv_delete_common) as ImageView
            iv_delete_common.setOnClickListener { toDeleteCommon(i) }
            tv_common1.setText(common_sentences!![i])
            iv_delete_common.visibility = View.VISIBLE
            ll_common_list!!.addView(view)
            //编辑常用语
            tv_common1.setOnClickListener( object : View.OnClickListener{
                override fun onClick(v: View?) {
                    var intent = Intent(act,ChatAddCommonActivity::class.java)
                    intent.putExtra("index",i)
                    intent.putExtra("content",common_sentences!![i])
                    startActivityForResult(intent,TO_ADD_COMMON)
                    overridePendingTransition(R.anim.push_bottom_in, R.anim.still)
                }

            })
        }
    }

    //删除common
    private fun toDeleteCommon(index: Int) {
        if (sender == null) {
            sender = CMHttpSender()
        }
        if (userBean == null) {
            return
        }
        val params = HashMap<String, String>()
        params.put("uid", userBean!!.uid)
        params.put("index", index.toString())
        try {
            sender.postWithTokenOnUI(this, CMRequestType.MASTER_DELETE_COMMON, params, AppConstants.SOURCE_SECRET, this)
        } catch (e: Exception) {
            BCBLog.d("", e)
        }

    }

    private fun initView() {
        tv_title!!.setText( "常用语")
        rl_add_common.setOnClickListener(this)
        iv_back.setOnClickListener(this)
    }



    override fun onBackPressed() {
        setResult(TO_CHANGE_COMMON)
        super.onBackPressed()
    }



    override fun onSuccess(tag: String, obj: Any?, headers: Array<Header>) {
        if (obj == null) {
            return
        }
        val data = obj as ChangeCommonResult?
        val code = data!!.code
        if (code == 0) {
            val result = data.result
            initCommon(result)
            return
        } else {
            ToastUtils.toast(this@ChatCommonActivity, data.message)
        }


    }


    override fun onFail(tag: String, code: Int, message: String, headers: Array<Header>) {
        ToastUtils.toast(this@ChatCommonActivity, message)
    }

    companion object {
        private val TO_CHANGE_COMMON = 30//去修改常用语
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        when(resultCode)
        {
            TO_ADD_COMMON->{
                if (data == null)
                {
                    return
                }
                val stringArrayExtra: ArrayList<String>? = data.getStringArrayListExtra("common_data")
                initCommon(stringArrayExtra)
            }
        }
    }

    private fun updateMechanic() {
        val userBean = MasterApplication.getInstance()!!.userBean ?: return
        //同步用户配置信息
        val map = HashMap<String, String>()
        map.put("uid", userBean.uid)
        val sender = CMHttpSender()
        try {
            sender.get(this, CMRequestType.MECHANIC_CONFIG, map, object : CMJsonCallback {
                override fun onSuccess(tag: String, obj: Any, headers: Array<Header>) {
                    var configResponse: ConfigResponseEntity? = null
                    try {
                        configResponse = obj as ConfigResponseEntity
                    } catch (e: Exception) {
                        BCBLog.d("", e)
                    }

                    try {
                        MasterApplication.setConfig(configResponse!!.result,this@ChatCommonActivity)
                    } catch (e: Exception) {
                        BCBLog.d("", e)
                    }

                }

                override fun onFail(tag: String, code: Int, message: String, headers: Array<Header>) {

                }
            })
        } catch (e: Exception) {
        }

    }
    override fun onClick(v: View?) {
      when(v!!.id)
      {
        R.id.rl_add_common->{
            var intent:Intent = Intent(this,ChatAddCommonActivity::class.java)
            startActivityForResult(intent,TO_ADD_COMMON)
            overridePendingTransition(R.anim.push_bottom_in, R.anim.still)
        }
          R.id.iv_back->{
              setResult(TO_CHANGE_COMMON)
              finish()
          }
      }
    }
}
