package com.bcb.master.ui

import android.annotation.SuppressLint
import android.content.Context
import android.content.Intent
import android.content.res.AssetManager
import android.media.AudioManager
import android.media.MediaPlayer
import android.os.Build
import android.os.Bundle
import android.os.Handler
import android.os.Vibrator
import android.text.TextUtils
import android.view.View
import com.bcb.master.AppConstants
import com.bcb.master.AppSession.isPushVideoDialogShow
import com.bcb.master.MasterApplication
import com.bcb.master.R
import com.bcb.master.model.PushNewVideoBean
import com.bcb.master.model.UserBean
import com.blankj.utilcode.util.ToastUtils
import com.blankj.utilcode.util.VibrateUtils
import com.jakewharton.rxbinding2.view.RxView
import com.loopj.http.bcb.CMJsonCallback
import com.loopj.http.bcb.CMRequestType
import com.loopj.http.entity.BaseEntity
import com.loopj.http.entity.QXQQuestionDetailBean
import com.loopj.http.entity.QXQVideoCallBean
import com.socks.library.KLog
import io.reactivex.Observable
import io.reactivex.android.schedulers.AndroidSchedulers
import kotlinx.android.synthetic.main.activity_qxq_push_dialog.*
import org.apache.http.Header
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode
import java.io.IOException
import java.util.concurrent.TimeUnit

class PushQxQVideoDialogActivity:BaseActivity() ,View.OnClickListener{
    var content :String = ""
    var question_id :String = ""
    var answer_uid :String = ""
    var videoId :String = ""
    lateinit var userBean:UserBean
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_qxq_push_dialog)
        initView()
        initData()
    }

    private fun initData() {
        playSoundNotify(this)
        userBean = MasterApplication.getInstance().userBean
        question_id = intent.getStringExtra("question_id")
        answer_uid = intent.getStringExtra("answer_uid")
        var params = HashMap<String, String>()
        params.put("question_id", question_id)
        params.put("uid", userBean.uid)
        sender.getWithTokenOnUI(this,CMRequestType.QXQ_QA_DETAIL,params,AppConstants.SOURCE_SECRET,object :CMJsonCallback{
            override fun onSuccess(tag: String?, obj: Any?, headers: Array<out Header>?) {
                    if (obj!=null)
                    {
                        var bean = obj as QXQQuestionDetailBean
                        if (bean.code == 0 && bean.result!=null)
                        {
                            var result = bean.result
                            content = result!!.content!!
                            videoId = result!!.request_video_call_id!!
                        }
                    }
            }

            override fun onFail(tag: String?, code: Int, message: String?, headers: Array<out Header>?) {
            }

        })
    }

    @SuppressLint("CheckResult")
    private fun initView() {
        EventBus.getDefault().register(this)
        isPushVideoDialogShow = true
        overridePendingTransition(0,0)
        tv_title.setText(getString(R.string.string_push_video_dialog))
        RxView.clicks(tv_confirm)
                .throttleFirst(3000, TimeUnit.MILLISECONDS)
                .subscribe {
                    getNewVideo()
                }
        tv_cancel.setOnClickListener(this)
    }

    private fun refuseVideo() {
        var params = HashMap<String, String>()
        params.put("question_id", question_id)
        params.put("uid", userBean.uid)
        params.put("video_call_id", videoId)
        params.put("content_type", "call")
        sender.postWithTokenOnUI(this, CMRequestType.QXQ_VIDEO_CONNECT_REFUSED, params, AppConstants.SOURCE_SECRET, object : CMJsonCallback {
            override fun onSuccess(tag: String?, obj: Any?, headers: Array<out Header>?) {
                if (obj != null) {
                    var data = obj as BaseEntity
                    if (data.code == 0) {
                        KLog.e(null,"成功！")
                    }
                }
            }

            override fun onFail(tag: String?, code: Int, message: String?, headers: Array<out Header>?) {
            }

        })
    }
    private val SOUND_NOTIFY_NAME = "sound_notify.mp3"
    private var player: MediaPlayer? = null

    /**
     * 播放通知声音
     *
     * @param pContext
     */
    private fun playSoundNotify(pContext: Context) {
        try {
            //震动
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                VibrateUtils.vibrate(longArrayOf(500, 1000, 1000, 2000, 2000, 1000), 0)
            }
            //调整播放音量
            val am = pContext.getSystemService(Context.AUDIO_SERVICE) as AudioManager
            am.setStreamVolume(AudioManager.STREAM_MUSIC,  /*修改第二个参数为一个固定的值，就是设置成功。
        下面的方法：获取音乐类型的音频流的最大值*/
                    am.getStreamMaxVolume(AudioManager.STREAM_MUSIC), AudioManager.FLAG_PLAY_SOUND)
            //播放通知音乐
            val assetManager: AssetManager
            player = MediaPlayer()
            assetManager = pContext.resources.assets

                val fileDescriptor = assetManager.openFd(SOUND_NOTIFY_NAME)
                player!!.setDataSource(fileDescriptor.fileDescriptor, fileDescriptor.startOffset, fileDescriptor.startOffset)
                player!!.prepare()
                player!!.start()
                player!!.setOnCompletionListener {
                    if (isPushVideoDialogShow)
                    {
                        player!!.start()
                        player!!.setLooping(true)
                    }
                }
                KLog.e("PushQxQVideoDialogActivity","player.start()")
            } catch (e: Exception) {
                e.printStackTrace()
            }
//        if (System.currentTimeMillis() - TOUCH_TIME < WAIT_TIME) {
//            PLAY_SOUND = false;
//            KLog.e("--------");
//        } else {
//            KLog.e("--------");
//            PLAY_SOUND = true;
//            TOUCH_TIME = System.currentTimeMillis();
//        }
    }
    override fun onDestroy() {
        if (player!=null)
        {
            player!!.stop()
            player!!.release()
            player = null
        }
        VibrateUtils.cancel()
        isPushVideoDialogShow = false
        super.onDestroy()
    }
    override fun onClick(v: View?) {
        when(v!!.id)
        {

            R.id.tv_cancel->{
               refuseVideo()
               finish()
               overridePendingTransition(0,0)

            }
        }
    }

    private fun getNewVideo() {
        var params = HashMap<String, String>()
        params.put("question_id", question_id)
        params.put("uid", userBean.uid)
        try {
            sender.getWithTokenOnUI(this, CMRequestType.QXQ_PULL_CALL, params, AppConstants.SOURCE_SECRET, object : CMJsonCallback {
                override fun onSuccess(tag: String?, obj: Any?, headers: Array<out Header>?) {
                    if (obj != null) {
                        var result = obj as QXQVideoCallBean
                        var data = result.result
                        if (result.code == 0 && data != null) {
                            var video_call_id = data.video_call_id
                            if (!TextUtils.isEmpty(video_call_id))
                            {
                                videoId = video_call_id!!
                                if (videoId!!.toInt() > 0) {
                                    //有视频咨询
                                    canVideo()
                                } else {
                                    AlreadyCloseVideo()
                                }
                            }else{
                                AlreadyCloseVideo()
                            }
                        }else{
                            AlreadyCloseVideo()
                        }
                    }
                }

                override fun onFail(tag: String?, code: Int, message: String?, headers: Array<out Header>?) {
                }

            })
        } catch (e: Exception) {
            KLog.e(e)
        }
    }

    private fun AlreadyCloseVideo() {
        ToastUtils.showLong("用户已挂断！")
        var intent = Intent(this, QXQChatActivity::class.java)
        intent.putExtra("question_id", question_id)
        intent.putExtra("question_content", content)
        startActivity(intent)
        KLog.e(null, "没有视频咨询或视频咨询以挂断！")
        finish()
    }


    override fun onBackPressed() {
//        super.onBackPressed()
//        overridePendingTransition(0, 0)
    }
    private fun canVideo() {
        if (TextUtils.isEmpty(content))
        {
            ToastUtils.showLong("操作太快了！")
            return
        }
       var a = Observable.just("")
               .observeOn(AndroidSchedulers.mainThread())
               .subscribe {
                   var intent = Intent(this,QXQChatActivity::class.java)
                   intent.putExtra("question_id",question_id)
                   intent.putExtra("question_content",content)
                   intent.putExtra("request_video_call_id",videoId)
                   startActivity(intent)
                   finish()
               }
    }
    @Subscribe(threadMode = ThreadMode.MAIN)
    fun closeDialog(event: PushNewVideoBean) {
        if (event.type == 7  && event.from_source == "qxq_wx_small")
        {
            finish()
        }
    }
}