package com.bcb.master.ui

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.bcb.master.AppConstants
import com.bcb.master.MasterApplication
import com.bcb.master.R
import com.bcb.master.adapter.QuestionVideoListAdapter
import com.bcb.master.fragment.LazyFragment
import com.blankj.utilcode.util.ToastUtils
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.loopj.http.bcb.CMJsonCallback
import com.loopj.http.bcb.CMRequestType
import com.loopj.http.entity.QXQQuestionListBean
import com.scwang.smart.refresh.footer.ClassicsFooter
import com.scwang.smart.refresh.header.ClassicsHeader
import com.scwang.smart.refresh.layout.api.RefreshLayout
import com.scwang.smart.refresh.layout.listener.OnLoadMoreListener
import com.scwang.smart.refresh.layout.listener.OnRefreshListener
import com.socks.library.KLog
import kotlinx.android.synthetic.main.activity_network.*
import kotlinx.android.synthetic.main.activity_nodata.*
import kotlinx.android.synthetic.main.fragment_video_list.*
import org.apache.http.Header

class QuestionVideoAnswerList : LazyFragment(), OnRefreshListener,OnLoadMoreListener,View.OnClickListener {
    lateinit var questionVideoListAdapter:QuestionVideoListAdapter
    lateinit var questionList:ArrayList<QXQQuestionListBean.VideoQuestionItem>
    var currentPage:String = "1"
    var totalPage:String = "1"
    val limit:String = "10"
    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        var view  = LayoutInflater.from(context).inflate(R.layout.fragment_video_list,null)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        initView()
        initData(false)
    }
    private fun initData(nextPage:Boolean) {
        KLog.e("qcds_bcb","---------------------")
        val userBean = MasterApplication.getInstance().userBean

        progress.visibility = View.VISIBLE
        var params = HashMap<String,String>()
        params.set("uid",userBean.uid)
        params.set("limit",limit)
        params.set("page",currentPage)
        sender.getWithTokenOnUI(context,CMRequestType.QXQ_VIDEO_LIST,params, AppConstants.SOURCE_SECRET,object :CMJsonCallback{
            override fun onSuccess(tag: String?, obj: Any?, headers: Array<out Header>?) {
                progress.visibility = View.GONE
                if (obj!=null)
                {
                    var questionBean = obj as QXQQuestionListBean
                    if (questionBean.code == 0)
                    {
                        KLog.json(Gson().toJson(questionBean))
                        var result  = questionBean.result
                        totalPage = result.total_page
                        if (result!=null)
                        {
                            if (nextPage)
                            {
                                questionList.addAll(questionBean.result.list)
                                questionVideoListAdapter.notifyDataSetChanged()
                            }else{
                                questionList = questionBean.result.list
                                showList(questionList)
                            }
                            stopRefreshSuccess()
                        }
                    }else{
                        ll_network.visibility = View.VISIBLE
                    }
                }
            }

            override fun onFail(tag: String?, code: Int, message: String?, headers: Array<out Header>?) {
                KLog.e("qcds_bcb","---------------------$message")
                ll_network.visibility = View.VISIBLE
                progress.visibility = View.GONE
                stopRefreshFail()
            }

        })
//        QXQ_VIDEO_LIST
    }

    private fun stopRefreshFail() {
        if (refreshLayout.isRefreshing)
        {
            refreshLayout.finishRefresh(false)
        }
        if (refreshLayout.isLoading)
        {
            refreshLayout.finishLoadMore(false)
        }
    }

    private fun stopRefreshSuccess() {
        if (refreshLayout.isRefreshing)
        {
            refreshLayout.finishRefresh()
        }
        if (refreshLayout.isLoading)
        {
            refreshLayout.finishLoadMore()
        }
    }

    private fun showList(list: List<QXQQuestionListBean.VideoQuestionItem>?) {
        if (list!!.size>0)
        {
            ll_none.visibility = View.GONE
            questionVideoListAdapter.setNewData(list)
        }else{
            ll_none.visibility = View.VISIBLE
        }
    }

    private fun initView() {
        refreshLayout.setRefreshHeader(ClassicsHeader(context))
        refreshLayout.setRefreshFooter(ClassicsFooter(context))
        refreshLayout.setOnRefreshListener(this)
        refreshLayout.setOnLoadMoreListener(this)
        tv_network.setOnClickListener(this)
        questionVideoListAdapter = QuestionVideoListAdapter()
        rv_video_list.layoutManager = LinearLayoutManager(context)
        rv_video_list.adapter = questionVideoListAdapter
        questionVideoListAdapter.setOnItemClickListener(object :BaseQuickAdapter.OnItemClickListener{
            override fun onItemClick(adapter: BaseQuickAdapter<*, *>?, view: View?, position: Int) {
                var quesiton = questionList.get(position)
                val intent = Intent(activity,QXQChatActivity::class.java)
                intent.putExtra("question_id",quesiton.question_id)
                activity!!.startActivity(intent)
            }

        })
    }

    override fun lazyLoad() {

    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        currentPage = "1"
        initData(false)
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        if (currentPage.equals(totalPage))
        {
            ToastUtils.showLong("没有下一页了！")
            refreshLayout.finishLoadMore()
            return
        }
        currentPage = (currentPage.toInt()+1).toString()
        initData(true)
    }

    override fun onClick(v: View) {
        when(v.id)
        {
            R.id.tv_network->{
                ll_network.visibility = View.GONE
                currentPage = "1"
                initData(false)
            }
        }
    }
}